##  Joule in SAP LeanIX
Joule is SAP's generative AI assistant that helps you access resources and find information through conversational interactions across the SAP ecosystem. Joule provides a natural language interface that works across SAP solutions, allowing you to navigate and retrieve information without manual searching.
In SAP LeanIX, Joule enables you to:
  * Search for diagrams and reports within SAP LeanIX
  * Search the inventory for fact sheets and view details
  * Get answers to questions about SAP LeanIX based on documentation
  * Find user subscriptions
  * Manage to-dos


For more information, see [Joule in SAP LeanIX](https://help.sap.com/docs/leanix/ea/joule-in-sap-leanix?locale=en-US&state=PRODUCTION&version=CLOUD "Joule is an AI assistant in SAP that helps you access resources and find information through conversational interactions. Learn how to access it and leverage its features.").
